################################################################################
# This is 'pine.pm', a ncm-pine's file
################################################################################
#
# VERSION:    1.2.7, 15/02/08 16:14
# AUTHOR:     Jaroslaw Polok <jaroslaw.polok@cern.ch>
# MAINTAINER: Jan.Iven@cern.ch
# LICENSE:    http://cern.ch/eu-datagrid/license.html
#
################################################################################
# Coding style: emulate <TAB> characters with 4 spaces, thanks!
################################################################################

package NCM::Component::pine;

#
# a few standard statements, mandatory for all components
#

use strict;
use NCM::Component;
use NCM::Check;

use vars qw(@ISA $EC);
@ISA = qw(NCM::Component);
$EC=LC::Exception::Context->new->will_store_all;

my $cfgfile='/etc/pine.conf';
my $mypath='/software/components/pine'; 


sub mySubst {
  my ($cfgfile,$key,$value)=@_;

  return NCM::Check::lines($cfgfile,
	linere => $key.'\s*=.*',
	goodre => $key.'='.quotemeta($value),
	good   => $key.'='.$value,
	keep   => 'first',
	add    => 'last',
	backup => '.old');

}

##########################################################################
sub Configure {
##########################################################################
  my ($self,$config)=@_;
  my $value="";
  my $userdomain="unknown domain";
  my $ret=0;

  unless ($NoAction) {
    if (-r $cfgfile) {
      if($config->elementExists($mypath."/userdomain")) {
	$userdomain=$config->getValue($mypath."/userdomain");
	$ret+=mySubst($cfgfile,'user-domain',$userdomain);
      }
      if($config->elementExists($mypath."/smtpserver")) {
	$ret+=mySubst($cfgfile,'smtp-server',$config->getValue($mypath."/smtpserver"));
      }
      if($config->elementExists($mypath."/nntpserver")) {
	$ret+=mySubst($cfgfile,'nntp-server',$config->getValue($mypath."/nntpserver"));
      }
      if($config->elementExists($mypath."/inboxpath")) {
	$ret+=mySubst($cfgfile,'inbox-path',$config->getValue($mypath."/inboxpath"));
      }
      if($config->elementExists($mypath."/foldercollection")) {
	$ret+=mySubst($cfgfile,'folder-collections',$config->getValue($mypath."/foldercollection"));
      }
      if($config->elementExists($mypath."/ldapserver")) {
	$ret+=mySubst($cfgfile,'ldap-servers',$config->getValue($mypath."/ldapservers"));
      }
      if($config->elementExists($mypath."/ldapnameattr")) {
	$ret+=mySubst($cfgfile,'name-attribute',$config->getValue($mypath."/ldapnameattr"));
      }
      if($config->elementExists($mypath."/disableauth")) {
	$ret+=mySubst($cfgfile,'disable-these-authenticators',$config->getValue($mypath."/disableauth"));
      }
    }
  }

  $self->OK("Configured pine for $userdomain") if ($ret);
  return;
}


##########################################################################
sub Unconfigure {
##########################################################################
  my ($self,$config)=@_;
   my $ret=0;
  unless ($NoAction) {


   $ret+=mySubst($cfgfile,'user-domain',' ');
   $ret+=mySubst($cfgfile,'smtp-server',' ');
   $ret+=mySubst($cfgfile,'nntp-server',' ');
   $ret+=mySubst($cfgfile,'inbox-path',' ');
   $ret+=mySubst($cfgfile,'folder-collections',' ');
   $ret+=mySubst($cfgfile,'ldap-servers',' ');
   $ret+=mySubst($cfgfile,'name-attribute',' ');
   $ret+=mySubst($cfgfile,'disable-these-authenticators',' ');
}
 $self->OK("Unconfigured pine for localhost") if ($ret);
 return; 
}
1; #required for Perl modules


### Local Variables: ///
### mode: perl ///
### End: ///
